==> haskell-resource-pool-0.2.3.2-310-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-CkmDKYKKBLkPXjnBxlb2n
key:                  resource-pool-0.2.3.2-CkmDKYKKBLkPXjnBxlb2n
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  a478b682bce772ef336eea1c70afaeb9
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.2.8/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-CkmDKYKKBLkPXjnBxlb2n
depends:
    base-4.16.4.0 hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    monad-control-1.0.3.1-J6JgsySNufR1aBAHpQ3Eh2 stm-2.5.0.2
    time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-ABNpRFPMzKw54ilqxg2n9F
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-311-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-Ba5fXlRT63RGrCuWQrH5UH
key:                  resource-pool-0.2.3.2-Ba5fXlRT63RGrCuWQrH5UH
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  2a22a1c11cff69391d9b7ca8dd52cacf
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.2.8/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-Ba5fXlRT63RGrCuWQrH5UH
depends:
    base-4.16.4.0 hashable-1.4.4.0-EsPTAmPpYqX3hovcHlHOLX
    monad-control-1.0.3.1-BUkxO6HLLlgCLFSdrHwBde stm-2.5.0.2
    time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-E6aYj1Nnyf1Hx206wlwDyN
    vector-0.13.1.0-IOwb1qSGKSdHIyg7Qp7MNu

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
